@@ -1545,7 +1545,9 @@ static int write_header(Grammar *g, char *base_pathname, char *tag) {
     strcat(pathname, ".d_parser.h");
     hfp = fopen(pathname, "w");
     if (!hfp) d_fail("unable to open `%s` for write\n", pathname);
-    d_version(ver);
+if (d_use_r_headers) {
+    fprintf(hfp, "#include <R.h>\n#include <Rinternals.h>\n#define printf Rprintf\n\n");}
+d_version(ver);
     fprintf(hfp, "/*\n  Generated by Make DParser Version %s\n", ver);
     fprintf(hfp, "  Available at https://github.com/jplevyak/dparser\n*/\n\n");
     fprintf(hfp, "#ifndef _%s_h\n", tag);
@@ -1717,7 +1719,9 @@ void write_parser_tables_internal(Grammar *g, char *base_pathname, char *tag, in
   if (!binary) {
     char ver[128];
     int header = write_header(g, base_pathname, tag);
-    d_version(ver);
+if (d_use_r_headers) {
+    fprintf(fp, "#include <R.h>\n#include <Rinternals.h>\n#define printf Rprintf\n\n");}
+d_version(ver);
     fprintf(fp, "/*\n  Generated by Make DParser Version %s\n", ver);
     fprintf(fp, "  Available at https://github.com/jplevyak/dparser\n*/\n\n");
     g->write_line = 7;
